@@ -107,55 +107,41 @@ def batch_fetch_properties(content, obj_type, properties):
 
             elif 'runtime.healthSystemRuntime.systemHealthInfo.numericSensorInfo' == prop.name:
                 """
-                    host hardware sensors alarms
+                    handle numericSensorInfo
                 """
-                try:
-                    alarms = list(
-                        'sensorInfo:{}:{}'.format(item.name.replace(' ', ''), item.healthState.key.lower())
-                        for item in prop.val if item.healthState.key.lower() not in ('green', 'unknown')
+                sensors = list(
+                    'numericSensorInfo:name={}:type={}:sensorStatus={}:value={}:unitModifier={}:unit={}'.format(
+                        item.name,
+                        item.sensorType,
+                        item.healthState.key,
+                        item.currentReading,
+                        item.unitModifier,
+                        item.baseUnits.lower()
                     )
-                except Exception:
-                    alarms = ['sensorInfo:AlarmsUnavailable:yellow']
+                    for item in prop.val
+                )
+                properties[prop.name] = ','.join(sensors)
 
-                properties[prop.name] = ','.join(alarms)
-
-            elif 'runtime.healthSystemRuntime.hardwareStatusInfo.cpuStatusInfo' == prop.name:
+            elif prop.name in [
+                'runtime.healthSystemRuntime.hardwareStatusInfo.cpuStatusInfo',
+                'runtime.healthSystemRuntime.hardwareStatusInfo.memoryStatusInfo',
+            ]:
                 """
-                    cpu status info alarms
+                    handle hardwareStatusInfo
                 """
-                try:
-                    alarms = list(
-                        'cpuStatusInfo:{}:{}'.format(item.name.replace(' ', ''), item.status.key.lower())
-                        for item in prop.val if item.status.key.lower() not in ('green', 'unknown')
+                sensors = list(
+                    'numericSensorInfo:name={}:type={}:sensorStatus={}:value={}:unitModifier={}:unit={}'.format(
+                        item.name,
+                        "n/a",
+                        item.status.key,
+                        "n/a",
+                        "n/a",
+                        "n/a",
                     )
-                except Exception:
-                    alarms = ['cpuStatusInfo:AlarmsUnavailable:yellow']
+                    for item in prop.val
+                )
+                properties[prop.name] = ','.join(sensors)
 
-                properties[prop.name] = ','.join(alarms)
-
-            elif 'runtime.healthSystemRuntime.hardwareStatusInfo.memoryStatusInfo' == prop.name:
-                """
-                    memory status info alarms
-                """
-                try:
-                    alarms = list(
-                        'memoryStatusInfo:{}:{}'.format(item.name.replace(' ', ''), item.status.key.lower())
-                        for item in prop.val if item.status.key.lower() not in ('green', 'unknown')
-                    )
-                except Exception:
-                    alarms = ['memoryStatusInfo:AlarmsUnavailable:yellow']
-
-                properties[prop.name] = ','.join(alarms)
-
-            # storage status info alarms - not included because they made no sense in here
-            # sine there are specific datastore alarms
-            #
-            # elif 'runtime.healthSystemRuntime.hardwareStatusInfo.storageStatusInfo' == prop.name:
-            #    alarms = list(
-            #            'storageStatusInfo:{}:{}'.format(item.name.replace(' ',''), item.status.key.lower())
-            #            for item in prop.val if item.status.key.lower() not in ('green', 'unknown')
-            #    )
-            #    properties[prop.name] = ','.join(alarms)
             else:
                 properties[prop.name] = prop.val
 
